pub struct EmbeddedRegion {
pub relative_to: LogicalRegion,
pub inner: Region,
}Expand description
An embedded region is a region entirely inside of another (often an output).
It can only be contained inside of another and cannot exceed its bounds.
Example:
ⓘ
┌─────────────┐
│ │
│ ┌──────────┼──────┐
│ │ │ ├──► Viewport
│ │ │ │
│ │ ├──────┼─────────────────┐
│ │ │xxxxxx│ │
│ │ │xxxxx◄├─── Inner region │
│ └──────────┼──────┘ │
│ │ │
│ │ Screen 2 ├──► Relative to
│ ├────────────────────────┘
│ │
│ Screen 1 │
└─────────────┘Fields
relative_to: LogicalRegionThe coordinate sysd
inner: RegionImplementations
Sourceimpl EmbeddedRegion
impl EmbeddedRegion
Sourcepub fn new(viewport: LogicalRegion, relative_to: LogicalRegion) -> Option<Self>
pub fn new(viewport: LogicalRegion, relative_to: LogicalRegion) -> Option<Self>
Given two LogicalRegions, one seen as the viewport and the other
relative_to (think the output we want to capture), create an
embedded region that is entirely inside of the relative_to region.
See EmbeddedRegion for an example ASCII visualisation.
Sourcepub fn logical(&self) -> LogicalRegion
pub fn logical(&self) -> LogicalRegion
Return the LogicalRegion of the embedded region.
Note that this remains a region of the same size, it’s not the inverse
of EmbeddedRegion::new which removes the parts that are outside of
the relative_to region.